@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2010  Warzone 2100 Project
+	Copyright (C) 2005-2011  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -24,23 +24,15 @@
  *
  */
 
-#include "frame.h"
-
-#include <string.h>
-#include <stdio.h>
 #include <time.h>
-#include "frameint.h"
-#include "string_ext.h"
 
+#include "frame.h"
 #if defined(WZ_HAVE_MOTIF)
 # include "x-motif-messagebox.h"
 #endif
 
-#include "lib/gamelib/gtime.h"
 #include "src/warzoneconfig.h"	// to determine if we are in full screen mode or not for the system dialogs
 
-extern void NotifyUserOfError(char *);		// will throw up a notifier on error
-
 #define MAX_LEN_LOG_LINE 512
 
 char last_called_script_event[MAX_EVENT_NAME_LEN];
