@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2010  Warzone 2100 Project
+	Copyright (C) 2005-2011  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -51,17 +51,9 @@ extern bool screenInitialise(UDWORD		width,			// Display width
 														// or full screen
 							 bool		vsync);
 
-
 /* Release the DD objects */
 extern void screenShutDown(void);
 
-/* In full screen mode flip to the GDI buffer.
- * Use this if you want the user to see any GDI output.
- * This is mainly used so that ASSERTs and message boxes appear
- * even in full screen mode.
- */
-extern void screenFlipToGDI(void);
-
 /* This is called once a frame so that the system can tell
  * whether a key was pressed this turn or held down from the last frame.
  */
