@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2010  Warzone 2100 Project
+	Copyright (C) 2005-2011  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -24,8 +24,6 @@
 #ifndef _frameresource_h
 #define _frameresource_h
 
-#include "lib/framework/frame.h"
-
 #if defined(__cplusplus)
 extern "C"
 {
@@ -34,9 +32,6 @@ extern "C"
 /** Maximum number of characters in a resource type. */
 #define RESTYPE_MAXCHAR		20
 
-/** Maximum number of characters in a resource ID. */
-#define RESID_MAXCHAR		40
-
 /** Function pointer for a function that loads from a memory buffer. */
 typedef bool (*RES_BUFFERLOAD)(const char *pBuffer, UDWORD size, void **pData);
 
@@ -91,9 +86,6 @@ extern bool resInitialise(void);
 /** Shutdown the resource module. */
 extern void resShutDown(void);
 
-/** Set the base resource directory. */
-extern void resSetBaseDir(const char* pResDir);
-
 /** Parse the res file. */
 bool resLoad(const char *pResFile, SDWORD blockID);
 
@@ -117,9 +109,6 @@ extern bool	resAddFileLoad(const char *pType, RES_FILELOAD fileLoad,
 /** Call the load function for a file. */
 extern bool resLoadFile(const char *pType, const char *pFile);
 
-/** Add data to the resource system. */
-extern bool resAddData(char *pType, char *pID, void *pData);
-
 /** Return the resource for a type and ID */
 extern void *resGetDataFromHash(const char *pType, UDWORD HashedID);
 extern void *resGetData(const char *pType, const char *pID);
