@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1992-2007  Trolltech ASA.
-	Copyright (C) 2005-2010  Warzone 2100 Project
+	Copyright (C) 2005-2011  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -20,11 +20,6 @@
 #include "frame.h"
 #include "stdio_ext.h"
 
-#include <stdio.h>
-#include <string.h>
-#include <assert.h>
-
-
 int vslcatprintf(char* str, size_t size, const char* format, va_list ap)
 {
 	size_t str_len;
