@@ -1,6 +1,6 @@
 /*
 	This file is part of Warzone 2100.
-	Copyright (C) 2007-2010  Warzone 2100 Project
+	Copyright (C) 2007-2011  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -20,12 +20,7 @@
 #ifndef VECTOR_H
 #define VECTOR_H
 
-#include "wzglobal.h"
-
-#include <assert.h>
-
 #include "fixedpoint.h"
-#include "types.h"
 #include "math_ext.h"
 
 
