@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2010  Warzone 2100 Project
+	Copyright (C) 2005-2011  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -214,6 +214,11 @@ void iV_SetFont(enum iV_fonts FontID)
 			glcFont(_glcFont_Regular);
 			break;
 
+		case font_scaled:
+			iV_SetTextSize(12.f * pie_GetVideoBufferHeight() / 480.f);
+			glcFont(_glcFont_Regular);
+			break;
+
 		case font_large:
 			iV_SetTextSize(21.f);
 			glcFont(_glcFont_Bold);
