@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2010  Warzone 2100 Project
+	Copyright (C) 2005-2011  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -175,7 +175,7 @@ BOOL scriptGetVarIndex(SCRIPT_CODE *psCode, char *pID, UDWORD *pIndex)
    these aren't currently checked for, but it's a lot clearer what's going on if they're all here */
 BOOL scriptTypeIsPointer(INTERP_TYPE type)
 {
-	ASSERT( ((type < ST_MAXTYPE) || (type >= VAL_REF)), "scriptTypeIsPointer: invalid type: %d", type );
+	ASSERT( ((type < (INTERP_TYPE)ST_MAXTYPE) || (type >= VAL_REF)), "scriptTypeIsPointer: invalid type: %d", type );
 	// any value or'ed with VAL_REF is a pointer
 	if (type >= VAL_REF) return true;
 	switch (type) {
