@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2010  Warzone 2100 Project
+	Copyright (C) 2005-2011  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@
 #include <string.h>
 
 #include "lib/framework/frame.h"
+#include "lib/framework/trig.h"
 #include "lib/gamelib/gtime.h"
 #include "lib/script/script.h"
 
@@ -990,25 +991,9 @@ static void actionHomeBasePos(SDWORD player, SDWORD *px, SDWORD *py)
 
 #define	VTOL_ATTACK_AUDIO_DELAY		(3*GAME_TICKS_PER_SEC)
 
-// Update the action state for a droid
-void actionUpdateDroid(DROID *psDroid)
+void actionSanity(DROID *psDroid)
 {
-	BASE_OBJECT			*psTarget;
-	PROPULSION_STATS	*psPropStats;
-	BOOL				(*actionUpdateFunc)(DROID *psDroid) = NULL;
-	signed int i;
-	unsigned int j;
-	//this is a bit field
-	bool nonNullWeapon[DROID_MAXWEAPS] = { false };
-	BASE_OBJECT			*psTargets[DROID_MAXWEAPS];
-	bool hasVisibleTarget = false;
-	bool targetVisibile[DROID_MAXWEAPS] = { false };
-	bool bHasTarget;
-
-	CHECK_DROID(psDroid);
-
-	psPropStats = asPropulsionStats + psDroid->asBits[COMP_PROPULSION].nStat;
-	ASSERT_OR_RETURN(, psPropStats != NULL, "Invalid propulsion stats pointer");
+	int i;
 
 	// clear the target if it has died
 	for (i = 0; i < DROID_MAXWEAPS; i++)
@@ -1040,6 +1025,29 @@ void actionUpdateDroid(DROID *psDroid)
 			}
 		}
 	}
+}
+
+// Update the action state for a droid
+void actionUpdateDroid(DROID *psDroid)
+{
+	BASE_OBJECT			*psTarget;
+	PROPULSION_STATS	*psPropStats;
+	BOOL				(*actionUpdateFunc)(DROID *psDroid) = NULL;
+	signed int i;
+	unsigned int j;
+	//this is a bit field
+	bool nonNullWeapon[DROID_MAXWEAPS] = { false };
+	BASE_OBJECT			*psTargets[DROID_MAXWEAPS];
+	bool hasVisibleTarget = false;
+	bool targetVisibile[DROID_MAXWEAPS] = { false };
+	bool bHasTarget;
+
+	CHECK_DROID(psDroid);
+
+	psPropStats = asPropulsionStats + psDroid->asBits[COMP_PROPULSION].nStat;
+	ASSERT_OR_RETURN(, psPropStats != NULL, "Invalid propulsion stats pointer");
+
+	actionSanity(psDroid);
 
 	//if the droid has been attacked by an EMP weapon, it is temporarily disabled
 	if (psDroid->lastHitWeapon == WSC_EMP)
@@ -1365,7 +1373,7 @@ void actionUpdateDroid(DROID *psDroid)
 		break;
 
 	case DACTION_ATTACK:
-		ASSERT_OR_RETURN( , psDroid->psActionTarget[0] != NULL, "target is NULL while attacking");
+		ASSERT_OR_RETURN(, psDroid->psActionTarget[0] != NULL, "target is NULL while attacking (droid %d, player %d)", psDroid->id, psDroid->player);
 
 		// don't wan't formations for this one
 		if (psDroid->sMove.psFormation)
