@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2010  Warzone 2100 Project
+	Copyright (C) 2005-2011  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -110,6 +110,9 @@ extern const char* getDroidActionName(DROID_ACTION action);
  */
 extern void actionUpdateDroid(DROID *psDroid);
 
+/** Do sanity update only. Called from actionUpdateDroid() normally. */
+void actionSanity(DROID *psDroid);
+
 /** Give a droid an action. */
 extern void actionDroid(DROID *psDroid, DROID_ACTION action);
 
