@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2010  Warzone 2100 Project
+	Copyright (C) 2005-2011  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@
 
 #include "lib/framework/frame.h"
 #include "lib/framework/math_ext.h"
+#include "lib/framework/trig.h"
 #include "lib/netplay/netplay.h"
 
 #include "objects.h"
@@ -422,8 +423,8 @@ void combFire(WEAPON *psWeap, BASE_OBJECT *psAttacker, BASE_OBJECT *psTarget, in
 		goto missed;
 	}
 
-	objTrace(psAttacker->id, "combFire: %u[%s]->%u: resultHitChance=%d, visibility=%hhu : ",
-	      psAttacker->id, psStats->pName, psTarget->id, resultHitChance, psTarget->visible[psAttacker->player]);
+	objTrace(psAttacker->id, "combFire: %u[%s]->%u: resultHitChance=%d, visibility=%d : ",
+	      psAttacker->id, psStats->pName, psTarget->id, resultHitChance, (int)psTarget->visible[psAttacker->player]);
 
 	return;
 
