@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2010  Warzone 2100 Project
+	Copyright (C) 2005-2011  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -1000,7 +1000,7 @@ static bool dataScriptLoad(const char* fileName, void **ppData)
 	pBuffer = malloc(fileSize * sizeof(char));
 	if (pBuffer == NULL)
 	{
-		debug(LOG_FATAL, "Fatal memory allocation, couldn't allocate %lld buffer", fileSize);
+		debug(LOG_FATAL, "Fatal memory allocation, couldn't allocate %ld buffer", (long)fileSize);
 		abort();
 	}
 
@@ -1067,7 +1067,7 @@ static bool dataScriptLoadVals(const char* fileName, void **ppData)
 	pBuffer = malloc(fileSize * sizeof(char));
 	if (pBuffer == NULL)
 	{
-		debug(LOG_FATAL, "Fatal memory allocation, couldn't allocate %lld buffer", fileSize);
+		debug(LOG_FATAL, "Fatal memory allocation, couldn't allocate %ld buffer", (long)fileSize);
 		abort();
 	}
 
