@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2010  Warzone 2100 Project
+	Copyright (C) 2005-2011  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -1920,10 +1920,10 @@ static void dealWithLMBDroid(DROID* psDroid, SELECTION_TYPE selection)
 				if(!psDroid->selected)
 				{
 					CONPRINTF(ConsoleString, (ConsoleString,
-											  _("%s - Damage %d%% - Experience %d, %s"),
+											  _("%s - Damage %d%% - Experience %.1f, %s"),
 											  droidGetName(psDroid),
 											  100 - clip(PERCENT(psDroid->body,psDroid->originalBody), 0, 100),
-											  (SDWORD) psDroid->experience, getDroidLevelName(psDroid)));
+											  psDroid->experience, _(getDroidLevelName(psDroid))));
 					
 					FeedbackOrderGiven();
 				}
@@ -2129,15 +2129,11 @@ static void dealWithLMBFeature(FEATURE* psFeature)
 							(BASE_STATS*) &asStructureStats[i],
 							psFeature->pos.x, psFeature->pos.y);
 					}
-					addConsoleMessage(_("Truck ordered to build Oil Derrick"),DEFAULT_JUSTIFY,SYSTEM_MESSAGE);
-		//				"Construction vehicle ordered to build a Derrick.",DEFAULT_JUSTIFY);
 					FeedbackOrderGiven();
 				}
 			}
 		}
-
 	}
-
 	else
 	{
 		switch(psFeature->psStats->subType)
@@ -2535,10 +2531,10 @@ static void dealWithRMB( void )
 							if(!psDroid->selected)
 							{
 								CONPRINTF(ConsoleString, (ConsoleString,
-									_("%s - Damage %d%% - Experience %d, %s"),
+									_("%s - Damage %d%% - Experience %.1f, %s"),
 									droidGetName(psDroid),
 									100 - clip(PERCENT(psDroid->body,psDroid->originalBody), 0, 100),
-									(SDWORD) psDroid->experience, getDroidLevelName(psDroid)));
+									psDroid->experience, _(getDroidLevelName(psDroid))));
 
 								FeedbackOrderGiven();
 							}
