@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2010  Warzone 2100 Project
+	Copyright (C) 2005-2011  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -46,7 +46,9 @@ back when building is destroyed*/
 
 #define DROID_RESISTANCE_FACTOR     30
 
-#define MAX_RECYCLED_DROIDS		32
+#define MAX_RECYCLED_DROIDS 100
+// Changing this breaks savegames!
+#define SAVE_RECYCLED_DROIDS 32
 
 //storage
 extern DROID_TEMPLATE			*apsDroidTemplates[MAX_PLAYERS];
