@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2010  Warzone 2100 Project
+	Copyright (C) 2005-2011  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -268,7 +268,11 @@ static void killEffect(EFFECT *e)
 		ASSERT(psTile, "Fire effect on non-existing tile (%d, %d)", posX, posY);
 		if (psTile)
 		{
-			psTile->tileInfoBits &= ~BITS_ON_FIRE;	// clear fire bit
+			psTile->firecount--;
+			if (psTile->firecount == 0)
+			{
+				psTile->tileInfoBits &= ~BITS_ON_FIRE;	// clear fire bit
+			}
 		}
 	}
 	effectStatus[e-asEffectsList] = ES_INACTIVE;
@@ -2249,6 +2253,7 @@ void	effectSetupFire(EFFECT *psEffect)
 	if (psTile)
 	{
 		psTile->tileInfoBits |= BITS_ON_FIRE;
+		psTile->firecount++;
 	}
 	psEffect->frameDelay = 300;	   // needs to be investigated...
 	psEffect->radius = auxVar;	// needs to be investigated
