@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2010  Warzone 2100 Project
+	Copyright (C) 2005-2011  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -28,6 +28,7 @@
 #include <SDL_thread.h>
 
 #include "lib/framework/frame.h"
+#include "lib/framework/trig.h"
 
 #include "objects.h"
 #include "map.h"
@@ -590,7 +591,7 @@ FPATH_RETVAL fpathDroidRoute(DROID* psDroid, SDWORD tX, SDWORD tY)
 // Run only from path thread
 static void fpathExecute(PATHJOB *psJob, PATHRESULT *psResult)
 {
-	FPATH_RETVAL retval = fpathAStarRoute(&psResult->sMove, psJob);
+	ASR_RETVAL retval = fpathAStarRoute(&psResult->sMove, psJob);
 
 	ASSERT(retval != ASR_OK || psResult->sMove.asPath, "Ok result but no path in result");
 	switch (retval)
