@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2010  Warzone 2100 Project
+	Copyright (C) 2005-2011  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -234,7 +234,7 @@ BOOL rebuildSearchPath( searchPathMode mode, BOOL force )
 	char tmpstr[PATH_MAX] = "\0";
 
 	if (mode != current_mode || force ||
-	    (use_override_mods && strcmp(override_mod_list, getModList())))
+	    (use_override_mods && strcmp(override_mod_list, getModList())) || use_override_map)
 	{
 		if (mode != mod_clean)
 		{
@@ -344,7 +344,7 @@ BOOL rebuildSearchPath( searchPathMode mode, BOOL force )
 #endif // DEBUG
 					// Add maps and global and multiplay mods
 					PHYSFS_addToSearchPath( curSearchPath->path, PHYSFS_APPEND );
-					addSubdirs( curSearchPath->path, "maps", PHYSFS_APPEND, NULL, false );
+					addSubdirs( curSearchPath->path, "maps", PHYSFS_APPEND, use_override_map?override_map:NULL, false );
 					addSubdirs( curSearchPath->path, "mods/music", PHYSFS_APPEND, NULL, false );
 					addSubdirs( curSearchPath->path, "mods/global", PHYSFS_APPEND, use_override_mods?override_mods:global_mods, true );
 					addSubdirs( curSearchPath->path, "mods", PHYSFS_APPEND, use_override_mods?override_mods:global_mods, true );
@@ -383,13 +383,13 @@ BOOL rebuildSearchPath( searchPathMode mode, BOOL force )
 				debug(LOG_ERROR, "Can't switch to unknown mods %i", mode);
 				return false;
 		}
-		if (use_override_mods && mode != mod_clean)
+		if ((use_override_mods || use_override_map) && mode != mod_clean)
 		{
-			if (strcmp(getModList(),override_mod_list))
+			if (use_override_mods && strcmp(getModList(),override_mod_list))
 			{
 				debug(LOG_POPUP, _("The required mod could not be loaded: %s\n\nWarzone will try to load the game without it."), override_mod_list);
 			}
-			clearOverrideMods();
+			clearOverrides();
 			current_mode = mod_override;
 		}
 
@@ -404,7 +404,7 @@ BOOL rebuildSearchPath( searchPathMode mode, BOOL force )
 	else if (use_override_mods)
 	{
 		// override mods are already the same as current mods, so no need to do anything
-		clearOverrideMods();
+		clearOverrides();
 	}
 	return true;
 }
@@ -920,11 +920,6 @@ BOOL stageTwoInitialise(void)
 		return false;
 	}
 
-	if(!InitRadar()) 	// After resLoad cause it needs the game palette initialised.
-	{
-		return false;
-	}
-
 	if(!initMiscImds())			/* Set up the explosions */
 	{
 		iV_ShutDown();
@@ -1034,6 +1029,11 @@ BOOL stageThreeInitialise(void)
 
 	loopMissionState = LMS_NORMAL;
 
+	if(!InitRadar()) 	// After resLoad cause it needs the game palette initialised.
+	{
+		return false;
+	}
+
 	// reset the clock to normal speed
 	gameTimeResetMod();
 
@@ -1130,10 +1130,6 @@ BOOL stageThreeInitialise(void)
 	return true;
 }
 
-
-
-
-
 /*****************************************************************************/
 /*      Shutdown before any data is released                                 */
 
@@ -1242,8 +1238,6 @@ static void	initMiscVars(void)
 	selectedPlayer = 0;
 	godMode = false;
 
-	// ffs am
-
 	radarOnScreen = true;
 	enableConsoleDisplay(true);
 
