@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2010  Warzone 2100 Project
+	Copyright (C) 2005-2011  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -815,14 +815,8 @@ void	kf_SystemClose( void )
 /* Zooms out from display */
 void	kf_ZoomOut( void )
 {
-	float zoomInterval = timeAdjustedIncrement(MAP_ZOOM_RATE, false);
-
-	distance += zoomInterval;
-	if(distance > MAXDISTANCE)
-	{
-		distance = MAXDISTANCE;
-	}
-	UpdateFogDistance(distance);
+	setViewDistance(MIN(getViewDistance() + timeAdjustedIncrement(MAP_ZOOM_RATE, false), MAXDISTANCE));
+	UpdateFogDistance(getViewDistance());
 }
 
 // --------------------------------------------------------------------------
@@ -854,14 +848,8 @@ void	kf_RadarZoomOut( void )
 /* Zooms in the map */
 void	kf_ZoomIn( void )
 {
-	float zoomInterval = timeAdjustedIncrement(MAP_ZOOM_RATE, false);
-
-	distance -= zoomInterval;
-	if (distance < MINDISTANCE)
-	{
-		distance = MINDISTANCE;
-	}
-	UpdateFogDistance(distance);
+	setViewDistance(MAX(getViewDistance() - timeAdjustedIncrement(MAP_ZOOM_RATE, false), MINDISTANCE));
+	UpdateFogDistance(getViewDistance());
 }
 
 // --------------------------------------------------------------------------
@@ -987,7 +975,7 @@ void	kf_PitchForward( void )
 void	kf_ResetPitch( void )
 {
 	player.r.x = DEG(360-20);
-	distance = START_DISTANCE;
+	setViewDistance(START_DISTANCE);
 }
 
 // --------------------------------------------------------------------------
@@ -2632,8 +2620,7 @@ void kf_ToggleRadarAllyEnemy(void)
 	{
 		CONPRINTF(ConsoleString, (ConsoleString, _("Radar showing player colors")));
 	}
-
-	resetRadarRedraw();
+	resizeRadar();
 }
 
 void kf_ToggleRadarTerrain(void)
