@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2010  Warzone 2100 Project
+	Copyright (C) 2005-2011  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -47,6 +47,7 @@
 #include "research.h"
 #include "lib/framework/lexer_input.h"
 #include "effects.h"
+#include "modding.h"
 
 extern int lev_get_lineno(void);
 extern char* lev_get_text(void);
@@ -677,6 +678,7 @@ BOOL levLoadData(const char* name, char *pSaveName, GAME_TYPE saveType)
 		}
 	}
 
+	setOverrideMap(psNewLevel->pName, psNewLevel->players);
 	if (!rebuildSearchPath(psNewLevel->dataDir, false))
 	{
 		return false;
