@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2010  Warzone 2100 Project
+	Copyright (C) 2005-2011  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -108,7 +108,6 @@ unsigned int loopStateChanges;
 static BOOL paused=false;
 static BOOL video=false;
 static BOOL bQuitVideo=false;
-static	SDWORD clearCount = 0;
 
 //holds which pause is valid at any one time
 typedef struct _pause_state
@@ -708,72 +707,43 @@ GAMECODE gameLoop(void)
 /* The video playback loop */
 void videoLoop(void)
 {
-	// There is something really odd here. - Per
 	static BOOL bActiveBackDrop = false;
+	const BOOL userSkip = keyPressed(KEY_ESC) || mouseReleased(MOUSE_LMB);
 
-#ifdef DEBUG
-	// Surely this should be: bActiveBackDrop = screen_GetBackDrop(); ?? - Per
-	// That would look odd, I tried it. Eg. intelligence screen is not redrawn correctly. -- DevU
-	screen_GetBackDrop();
-#endif
+	if (screen_GetBackDrop())
+	{
+		bActiveBackDrop = true;
+		screen_StopBackDrop();
+	}
+	else
+	{
+		bActiveBackDrop = false;
+	}
 
 	if (loop_GetVideoStatus())
 	{
 		bQuitVideo = !seq_UpdateFullScreenVideo(NULL);
 	}
 
-	//toggling display mode disabled in video mode
-	// Check for quit
-	if (keyPressed(KEY_ESC) || mouseReleased(MOUSE_LMB))
+	pie_ScreenFlip(CLEAR_BLACK); // videoloopflip
+
+	// if the video finished or user is skipping the video
+	if (bQuitVideo || userSkip)
 	{
 		seq_StopFullScreenVideo();
 		bQuitVideo = false;
 
-		// remove the intelligence screen if necessary
-		if (messageIsImmediate())
+		// set the next video off - if any - if the user isn't skipping
+		if (seq_AnySeqLeft() && !userSkip)
 		{
-			intResetScreen(true);
-			setMessageImmediate(false);
-		}
-		//Script callback for video over
-		//don't do the callback if we're playing the win/lose video
-		if (!getScriptWinLoseVideo())
-		{
-			eventFireCallbackTrigger((TRIGGER_TYPE)CALL_VIDEO_QUIT);
-		}
-		else
-		{
-			displayGameOver(getScriptWinLoseVideo() == PLAY_WIN);
-		}
-		pie_ScreenFlip(CLEAR_BLACK);// videoloopflip extra mar10
-
-		if (bActiveBackDrop)
-		{
-			// We never get here presently - Per
- 			screen_RestartBackDrop();
-		}
-	}
-
-	//if the video finished...
-	if (bQuitVideo)
-	{
-		seq_StopFullScreenVideo();
-		bQuitVideo = false;
-
-		//set the next video off - if any
-		if (seq_AnySeqLeft())
-		{
-			pie_ScreenFlip(CLEAR_BLACK);// videoloopflip extra mar10
-
-			if (bActiveBackDrop)
-			{
-				screen_RestartBackDrop();
-			}
-		 	//bClear = CLEAR_BLACK;
 			seq_StartNextFullScreenVideo();
 		}
 		else
 		{
+			if (bActiveBackDrop)
+			{
+				screen_RestartBackDrop();
+			}
 			// remove the intelligence screen if necessary
 			if (messageIsImmediate())
 			{
@@ -789,34 +759,8 @@ void videoLoop(void)
 			{
 				displayGameOver(getScriptWinLoseVideo() == PLAY_WIN);
 			}
-			pie_ScreenFlip(CLEAR_BLACK);// videoloopflip extra mar10
-
-			if (bActiveBackDrop)
-			{
-				// We never get here presently - Per
-				screen_RestartBackDrop();
-			}
 		}
 	}
-
-	if( clearCount < 1)
-	{
-		if (screen_GetBackDrop())
-		{
-			bActiveBackDrop = true;
-			screen_StopBackDrop();
-		}
-		else
-		{
-			bActiveBackDrop = false;
-			screen_StopBackDrop();
-		}
-	}
-
-	clearCount++;
-
-	pie_ScreenFlip(CLEAR_BLACK);// videoloopflip
-
 }
 
 
@@ -825,7 +769,6 @@ void loop_SetVideoPlaybackMode(void)
 	videoMode += 1;
 	paused = true;
 	video = true;
-	clearCount = 0;
 	gameTimeStop();
 	pie_SetFogStatus(false);
 	audio_StopAll();
