@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2010  Warzone 2100 Project
+	Copyright (C) 2005-2011  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -107,6 +107,8 @@ char * multiplay_mods[MAX_MODS] = { NULL };
 char * override_mods[MAX_MODS] = { NULL };
 char * override_mod_list = NULL;
 bool use_override_mods = false;
+char * override_map[2] = { NULL };
+bool use_override_map = false;
 
 char * loaded_mods[MAX_MODS] = { NULL };
 char * mod_list = NULL;
@@ -250,7 +252,29 @@ void setOverrideMods(char * modlist)
 	override_mod_list = modlist;
 	use_override_mods = true;
 }
-void clearOverrideMods(void)
+void setOverrideMap(char* map, int maxPlayers)
+{
+	// Transform "Sk-Rush-T2" into "4c-Rush.wz" so it can be matched by the map loader
+	override_map[0] = (char*)malloc(strlen(map)+1+7);
+	snprintf(override_map[0], 3, "%d", maxPlayers);
+	strcat(override_map[0],"c-");
+	if (strncmp(map, "Sk-", 3) == 0)
+	{
+		strcat(override_map[0],map+3);
+	}
+	else
+	{
+		strcat(override_map[0],map);
+	}
+	if (strncmp(override_map[0]+strlen(override_map[0])-3,"-T",2) == 0)
+	{
+		override_map[0][strlen(override_map[0])-3] = '\0';
+	}
+	strcat(override_map[0],".wz");
+	override_map[1] = NULL;
+	use_override_map = true;
+}
+void clearOverrides(void)
 {
 	int i;
 	use_override_mods = false;
@@ -260,6 +284,13 @@ void clearOverrideMods(void)
 	}
 	override_mods[0] = NULL;
 	override_mod_list = NULL;
+
+	if (override_map[0])
+	{
+		free(override_map[0]);
+		override_map[0] = NULL;
+	}
+	use_override_map = false;
 }
 
 void addLoadedMod(const char * modname)
@@ -705,7 +736,7 @@ static void startGameLoop(void)
 {
 	SetGameMode(GS_NORMAL);
 
-	if (!levLoadData(aLevelName, NULL, 0))
+	if (!levLoadData(aLevelName, NULL, GTYPE_SCENARIO_START))
 	{
 		debug( LOG_FATAL, "Shutting down after failure" );
 		exit(EXIT_FAILURE);
