@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2010  Warzone 2100 Project
+	Copyright (C) 2005-2011  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -844,7 +844,7 @@ static void saveMissionData(void)
 	//clear all the effects from the map
 	initEffectsSystem();
 
-	resetRadarRedraw();
+	resizeRadar();
 }
 
 /*
@@ -927,19 +927,12 @@ void restoreMissionData(void)
 	//reset the current structure lists
 	setCurrentStructQuantity(false);
 
-	//initPlayerPower();
-
 	initFactoryNumFlag();
 	resetFactoryNumFlag();
 
-	//terrain types? - hopefully not! otherwise we have to load in the terrain texture pages.
-
-	//reset the game time
-	//gameTimeReset(mission.startTime);
-
 	offWorldKeepLists = false;
 
-	resetRadarRedraw();
+	resizeRadar();
 
 	// reset the environ map back to the homebase settings
 	environReset();
