@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2010  Warzone 2100 Project
+	Copyright (C) 2005-2011  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -26,7 +26,8 @@ void removeSubdirs( const char * basedir, const char * subdir, char * checkList[
 void printSearchPath( void );
 
 void setOverrideMods(char * modlist);
-void clearOverrideMods(void);
+void setOverrideMap(char* map, int maxPlayers);
+void clearOverrides(void);
 
 void addLoadedMod(const char * modname);
 void clearLoadedMods(void);
