@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2010  Warzone 2100 Project
+	Copyright (C) 2005-2011  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -1149,7 +1149,7 @@ BOOL recvDestroyDroid()
 	if(!psDroid->died)
 	{
 		turnOffMultiMsg(true);
-		debug(LOG_DEATH, "Killing droid %d on request from player %d", psDroid->id, NETgetSource());
+		debug(LOG_DEATH, "Killing droid %d on request from player %d \"%s\"", psDroid->id, NETgetSource(), getPlayerName(NETgetSource()));
 		destroyDroid(psDroid);
 		turnOffMultiMsg(false);
 	}
