@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2010  Warzone 2100 Project
+	Copyright (C) 2005-2011  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -120,20 +120,16 @@ void radarInitVars(void)
 	radarSize(RadarZoom);
 }
 
-//called for when a new mission is started
-void resetRadarRedraw()
-{
-	// make sure Radar buffer is correct
-	resizeRadar();
-}
-
 BOOL InitRadar(void)
 {
 	// Ally/enemy/me colors
 	colRadarAlly = WZCOL_YELLOW;
 	colRadarEnemy = WZCOL_RED;
 	colRadarMe = WZCOL_WHITE;
-
+	if (mapWidth < 150 && pie_GetVideoBufferHeight() > 480)	// too small!
+	{
+		RadarZoom = DEFAULT_RADARZOOM * 2;
+	}
 	pie_InitRadar();
 
 	return true;
@@ -556,7 +552,7 @@ static void RotateVector2D(Vector3i *Vector, Vector3i *TVector, Vector3i *Pos, i
 static SDWORD getDistanceAdjust( void )
 {
 	UDWORD	origDistance = MAXDISTANCE;
-	SDWORD	dif = MAX(origDistance - distance, 0);
+	SDWORD	dif = MAX(origDistance - getViewDistance(), 0);
 
 	return dif / 100;
 }
