@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2010  Warzone 2100 Project
+	Copyright (C) 2005-2011  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -562,31 +562,6 @@ BOOL scrGroupObjGet(UDWORD index)
 		return false;
 	}
 
-	//fix: turn off caching, since it can screw up everything if returns outdated values
-	// recalculate the values if necessary
-/*
-	if (lgGameTime != gameTime || psScrLastGroup != psGroup)
-	{
-		lgGameTime = gameTime;
-		psScrLastGroup = psGroup;
-		lgMembers = 0;
-		lgHealth = 0;
-		lgX = lgY = 0;
-		for(psCurr = psGroup->psList; psCurr; psCurr = psCurr->psGrpNext)
-		{
-			lgMembers += 1;
-			lgX += (SDWORD)psCurr->pos.x;
-			lgY += (SDWORD)psCurr->pos.y;
-			lgHealth += (SDWORD)((100 * psCurr->body)/psCurr->originalBody);
-		}
-		if (lgMembers > 0)
-		{
-			lgX = lgX / lgMembers;
-			lgY = lgY / lgMembers;
-			lgHealth = lgHealth / lgMembers;
-		}
-	}
-*/
 	switch (index)
 	{
 	case GROUPID_POSX:
@@ -765,9 +740,6 @@ BOOL scrValDefSave(INTERP_VAL *psVal, char *pBuffer, UDWORD *pSize)
 	RESEARCH	*psResearch;
 	char		*pPos;
 	DROID		*psCDroid;
-#ifdef _DEBUG
-	BASE_OBJECT	*psObj;
-#endif
 
 	switch (psVal->type)
 	{
@@ -798,19 +770,14 @@ BOOL scrValDefSave(INTERP_VAL *psVal, char *pBuffer, UDWORD *pSize)
 		// just save the id
 		if (pBuffer)
 		{
-			if (psVal->v.oval == NULL)
+			if (psVal->v.oval == NULL || ((BASE_OBJECT *)psVal->v.oval)->died > 1 || !getBaseObjFromId(((BASE_OBJECT *)psVal->v.oval)->id))
 			{
 				*((UDWORD*)pBuffer) = UDWORD_MAX;
 			}
 			else
 			{
 				*((UDWORD*)pBuffer) = ((BASE_OBJECT *)psVal->v.oval)->id;
-#ifdef _DEBUG
-				psObj = getBaseObjFromId(((BASE_OBJECT *)psVal->v.oval)->id);
-				ASSERT( psObj == (BASE_OBJECT *)psVal->v.oval,"scrValDefSave failed to find object, continue" );
-#endif
 			}
-
 			endian_udword((UDWORD*)pBuffer);
 		}
 		*pSize = sizeof(UDWORD);
@@ -1197,26 +1164,8 @@ BOOL scrValDefLoad(SDWORD version, INTERP_VAL *psVal, char *pBuffer, UDWORD size
 				 *
 				 * Thus loading of these strings is practically impossible.
 				 */
-#if 0
-				const char * const str = strresGetString(psStringRes, id);
-				if (!str)
-				{
-					debug(LOG_FATAL, "Couldn't find string with id %u", id);
-					abort();
-					return false;
-				}
-
-				psVal->v.sval = strdup(str);
-				if (!psVal->v.sval)
-				{
-					debug(LOG_FATAL, "Out of memory");
-					abort();
-					return false;
-				}
-#else
 				debug(LOG_ERROR, "Incompatible savegame format version %u, should be at least version 4", (unsigned int)version);
 				return false;
-#endif
 			}
 		}
 		else
@@ -1389,14 +1338,12 @@ BOOL scrValDefLoad(SDWORD version, INTERP_VAL *psVal, char *pBuffer, UDWORD size
 				psCDroid = (DROID *)getBaseObjFromId(id);
 				if (!psCDroid)
 				{
-					debug( LOG_FATAL, "scrValDefLoad: couldn't find object id %d", id );
-					abort();
+					debug(LOG_INFO, "Could not find object id %d", id);
 				}
 				else
 				{
 					grpJoin((DROID_GROUP*)(psVal->v.oval), psCDroid);
 				}
-
 				pPos += sizeof(UDWORD);
 				members -= 1;
 			}
@@ -1425,7 +1372,7 @@ BOOL scrValDefLoad(SDWORD version, INTERP_VAL *psVal, char *pBuffer, UDWORD size
 			if (!index)			//this is a NON fatal error.
 			{
 				// We can't find filename of the sound for some reason.
-				debug(LOG_ERROR, "Sound ID not available %s not found", pName);
+				debug(LOG_INFO, "Sound ID not available %s not found", pName);
 				break;
 			}
 		}
