@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2010  Warzone 2100 Project
+	Copyright (C) 2005-2011  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -286,8 +286,11 @@ void visRemoveVisibility(BASE_OBJECT *psObj)
 			const TILEPOS pos = psObj->watchedTiles[i];
 			MAPTILE *psTile = mapTile(pos.x, pos.y);
 
-			ASSERT(psTile->watchers[psObj->player] > 0, "Not watching watched tile (%d, %d)", (int)pos.x, (int)pos.y);
-			psTile->watchers[psObj->player]--;
+			//ASSERT(psTile->watchers[psObj->player] > 0, "Not watching watched tile (%d, %d)", (int)pos.x, (int)pos.y);
+			if (psTile->watchers[psObj->player] > 0)
+			{
+				psTile->watchers[psObj->player]--;
+			}
 		}
 		free(psObj->watchedTiles);
 		psObj->watchedTiles = NULL;
